@@ -1,14 +1,18 @@
 package bmc
 
+import (
+	"net/url"
+)
+
 func init() {
 	registerFactory("irmc", newIRMCAccessDetails)
 }
 
-func newIRMCAccessDetails(bmcType, portNum, hostname, path string) (AccessDetails, error) {
+func newIRMCAccessDetails(parsedURL *url.URL) (AccessDetails, error) {
 	return &iRMCAccessDetails{
-		bmcType:  bmcType,
-		portNum:  portNum,
-		hostname: hostname,
+		bmcType:  parsedURL.Scheme,
+		portNum:  parsedURL.Port(),
+		hostname: parsedURL.Hostname(),
 	}, nil
 }
 
@@ -54,3 +58,19 @@ func (a *iRMCAccessDetails) DriverInfo(bmcCreds Credentials) map[string]interfac
 func (a *iRMCAccessDetails) BootInterface() string {
 	return "pxe"
 }
+
+func (a *iRMCAccessDetails) ManagementInterface() string {
+	return ""
+}
+
+func (a *iRMCAccessDetails) PowerInterface() string {
+	return ""
+}
+
+func (a *iRMCAccessDetails) RAIDInterface() string {
+	return ""
+}
+
+func (a *iRMCAccessDetails) VendorInterface() string {
+	return ""
+}
